RecountFu.consoleOptions = {
  type = 'group',
  args = {
    reset = {
      name = "Reset",
      desc = "Resets the data",
      type = 'execute',
      func = function() Recount:ResetData() end
    },
    verchk = {
      name = "VerChk",
      desc = "Displays the versions of players in the raid",
      type = 'execute',
      func = function() Recount:Print("Displaying Versions") if Recount.VerTable~=nil then for k,v in pairs(Recount.VerTable) do Recount:Print(k.." "..v) end end end
    },
    show = {
      name = "Show",
      desc = "Shows the main window",
      type = 'execute',
      func = function() Recount.MainWindow:Show();Recount:RefreshMainWindow() end
    },
    hide = {
      name = "Hide",
      desc = "Hides the main window",
      type = 'execute',
      func = function() Recount.MainWindow:Hide() end
    },
    toggle = {
      name = "Toggle",
      desc = "Toggles the main window",
      type = 'execute',
      func = function() if Recount.MainWindow:IsShown() then Recount.MainWindow:Hide() else Recount.MainWindow:Show();Recount:RefreshMainWindow() end end
    },
    report = {
      name = "Report",
      type = 'group',
      desc = "Allows the data of a window to be reported",
      args = {
        detail = {
          name = "Detail",
          desc = "Reports the Detail Window Data",
          type = 'execute',
          func = function()  Recount:ShowReport("Detail",Recount.ReportDetail) end
        },
        main ={
          name = "Main",
          desc = "Reports the Main Window Data",
          type = 'execute',
          func = function()  Recount:ShowReport("Main",Recount.ReportData) end
        }
      }
    },
    selectmode = {
      name = "Select View Mode...",
      type = 'group',
      desc = "Select which view mode to display.",
      args = {
		-- Elsia: These will be now auto-generated from Recount's MainWindowModes
      }
    },      
    config = {
      name = "Config",
      desc = "Shows the config window",
      type = 'execute',
      func = function() Recount:ShowConfig() end
    },
    resetpos = {
      name = "ResetPos",
      desc = "Resets the positions of the detail, graph, and main windows",
      type = 'execute',
      func = function() Recount:ResetPositions() end
    },
    lock = {
      name  = "Lock",
      desc = "Toggles windows being locked",
      type = 'toggle',
      get = function() return Recount.db.char.Locked end,
      set = function(v)
        Recount.db.char.Locked=v 
        Recount:LockWindows(v)
      end,
      map = { [false] = "|cffff4040Disabled|r", [true] = "|cff40ff40Enabled|r" }
    },
    unknownSpells = {
      name = "Unknown Spells",
      desc = "Shows found unknown spells in BabbleSpell",
      type = 'execute',
      func = function() Recount:Print("Unknown Spells:");for k in pairs(Recount.UnknownSpells) do Recount:Print(k) end end
    },
    realtime = {
      name = "Realtime",
      type = 'group',
      desc = "Specialized Realtime Graphs",
      args = {
        fps = {
          name = "FPS",
          desc = "Starts a realtime window tracking your FPS",
          type = 'execute',
          func = function() Recount:CreateRealtimeWindow("FPS","FPS","") end
        },
        lag = {
          name = "Lag",
          desc = "Starts a realtime window tracking your latency",
          type = 'execute',
          func = function() Recount:CreateRealtimeWindow("Latency","LAG","") end
        },
        uptraffic = {
          name = "Upstream Traffic",
          desc = "Starts a realtime window tracking your upstream traffic",
          type = 'execute',
          func = function() Recount:CreateRealtimeWindow("Upstream Traffic","UP_TRAFFIC","") end
        },
        downtraffic = {
          name = "Downstream Traffic",
          desc = "Starts a realtime window tracking your downstream traffic",
          type = 'execute',
          func = function() Recount:CreateRealtimeWindow("Downstream Traffic","DOWN_TRAFFIC","") end
        },
        bandwidth = {
          name = "Available Bandwidth",
          desc = "Starts a realtime window tracking amount of available AceComm bandwidth left",
          type = 'execute',
          func = function() Recount:CreateRealtimeWindow("Bandwidth Available","AVAILABLE_BANDWIDTH","") end
        },
        raid = {
          name = "Raid",
          desc = "Tracks your entire raid",
          type = 'group',

          args = {
            dps = {
              name = "DPS",
              desc = "Tracks Raid Damage Per Second",
              type = 'execute',
              func = function() Recount:CreateRealtimeWindow("!RAID","DAMAGE","Raid DPS") end
            },
            dtps = {
              name = "DTPS",
              desc = "Tracks Raid Damage Taken Per Second",
              type = 'execute',
              func = function() Recount:CreateRealtimeWindow("!RAID","DAMAGETAKEN","Raid DTPS") end
            },
            hps = {
              name = "HPS",
              desc = "Tracks Raid Healing Per Second",
              type = 'execute',
              func = function() Recount:CreateRealtimeWindow("!RAID","HEALING","Raid HPS") end
            },
            htps = {
              name = "HTPS",
              desc = "Tracks Raid Healing Taken Per Second",
              type = 'execute',
              func = function() Recount:CreateRealtimeWindow("!RAID","HEALINGTAKEN","Raid HTPS") end
            },
          }
        }
      }
    },
    --Added by Physical
    textOptions = {
      name = "Text Options",
      desc = "Options for Displaying Text in Fubar",
      type = 'group',
      args = {
            Update_Time = {
                  type = 'range',
                  name = "Update Frequency",
                  desc = "How Frequently to update text on the Fubar Toolbar (In Seconds)",
                  get = function() return RecountFu.db.profile.text.update_time end,
                  set = function(v) RecountFu.db.profile.text.update_time = v; RecountFu:UpdateTimeChanged() end,
                  min = 0.1,
                  max = 5,
                  step = 0.1,
                  order = 3,
            },      
            DPS = {
                type = 'toggle',
                name = "Show DPS",
                desc = "Show DPS in Fubar Toolbar",
                get = function() return RecountFu.db.profile.text.show_dps end,
                set = function(v) RecountFu.db.profile.text.show_dps = v; RecountFu:UpdateText(); RecountFu:UpdateTimeChanged() end,
                order = 1
            },
			DPS_Raid = {
					type = 'text',
                    name = "Self/Raid DPS",
                    desc = "Show Self or Raid DPS",
					get = function() return RecountFu.db.profile.text.dps_raid end,
					set = function(v) RecountFu.db.profile.text.dps_raid = v; RecountFu:UpdateText() end,
					validate = {
                        SelfDPS = "SelfDPS",
                        RaidDPS = "RaidDPS"
                    },
					order = 1
                },
            DPS_Type = {
					type = 'text',
                    name = "DPS Type",
                    desc = "Pick DPS type Output to Fubar",
					get = function() return RecountFu.db.profile.text.dps_type end,
					set = function(v) RecountFu.db.profile.text.dps_type = v; RecountFu:UpdateText() end,
					validate = {
                        Overall = "Overall",
                        LastFight = "Last Fight"
                    },
					order = 2
                },
            },
        }, 
      }
    --End Add
}

for k,v in pairs(Recount.MainWindowData) do
	RecountFu.consoleOptions.args.selectmode.args["selectmode"..k]=
	{
		name = v[1],
		desc = "Displays the "..v[1].." mode.",
		type = 'execute',
		func = function() Recount:SetMainWindowMode(k)  end
	}
end


RecountFu.OnMenuRequest = RecountFu.consoleOptions;
RecountFu:RegisterChatCommand({"/recfu"}, RecountFu.consoleOptions)